=======
History
=======

0.2.3 (2022-11-21)
-------------------

* fix the issue where the package wasn't building due to Jinja / Markupplus.

0.2.2 (2022-11-21)
------------------

* Fix issue with requirements not being correct.

0.2.1 (2022-11-15)
------------------

* Fix issue where dependencies weren't bundling

0.2.0 (2022-11-15)
------------------

* Add salary extractor.
* Add skill extractor.
* Add testing for the extractors.
* Add trained model.

0.1.0 (2022-11-10)
------------------

* First release on PyPI.
